# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WemCoachingAppointmentTopicCoachingAppointmentNotification(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WemCoachingAppointmentTopicCoachingAppointmentNotification - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_start': 'datetime',
            'length_in_minutes': 'int',
            'status': 'str',
            'facilitator': 'WemCoachingAppointmentTopicUserReference',
            'attendees': 'list[WemCoachingAppointmentTopicUserReference]',
            'created_by': 'WemCoachingAppointmentTopicUserReference',
            'date_created': 'datetime',
            'modified_by': 'WemCoachingAppointmentTopicUserReference',
            'date_modified': 'datetime',
            'conversations': 'list[WemCoachingAppointmentTopicCoachingAppointmentConversation]',
            'documents': 'list[WemCoachingAppointmentTopicCoachingAppointmentDocument]',
            'change_type': 'str',
            'date_completed': 'datetime',
            'external_links': 'list[WemCoachingAppointmentTopicCoachingAppointmentExternalLink]'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_start': 'dateStart',
            'length_in_minutes': 'lengthInMinutes',
            'status': 'status',
            'facilitator': 'facilitator',
            'attendees': 'attendees',
            'created_by': 'createdBy',
            'date_created': 'dateCreated',
            'modified_by': 'modifiedBy',
            'date_modified': 'dateModified',
            'conversations': 'conversations',
            'documents': 'documents',
            'change_type': 'changeType',
            'date_completed': 'dateCompleted',
            'external_links': 'externalLinks'
        }

        self._id = None
        self._name = None
        self._date_start = None
        self._length_in_minutes = None
        self._status = None
        self._facilitator = None
        self._attendees = None
        self._created_by = None
        self._date_created = None
        self._modified_by = None
        self._date_modified = None
        self._conversations = None
        self._documents = None
        self._change_type = None
        self._date_completed = None
        self._external_links = None

    @property
    def id(self):
        """
        Gets the id of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :return: The id of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :param id: The id of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :return: The name of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :param name: The name of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :type: str
        """
        
        self._name = name

    @property
    def date_start(self):
        """
        Gets the date_start of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :return: The date_start of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :rtype: datetime
        """
        return self._date_start

    @date_start.setter
    def date_start(self, date_start):
        """
        Sets the date_start of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :param date_start: The date_start of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :type: datetime
        """
        
        self._date_start = date_start

    @property
    def length_in_minutes(self):
        """
        Gets the length_in_minutes of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :return: The length_in_minutes of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :rtype: int
        """
        return self._length_in_minutes

    @length_in_minutes.setter
    def length_in_minutes(self, length_in_minutes):
        """
        Sets the length_in_minutes of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :param length_in_minutes: The length_in_minutes of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :type: int
        """
        
        self._length_in_minutes = length_in_minutes

    @property
    def status(self):
        """
        Gets the status of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :return: The status of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :param status: The status of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :type: str
        """
        allowed_values = ["Scheduled", "InProgress", "Completed", "InvalidSchedule"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def facilitator(self):
        """
        Gets the facilitator of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :return: The facilitator of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :rtype: WemCoachingAppointmentTopicUserReference
        """
        return self._facilitator

    @facilitator.setter
    def facilitator(self, facilitator):
        """
        Sets the facilitator of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :param facilitator: The facilitator of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :type: WemCoachingAppointmentTopicUserReference
        """
        
        self._facilitator = facilitator

    @property
    def attendees(self):
        """
        Gets the attendees of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :return: The attendees of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :rtype: list[WemCoachingAppointmentTopicUserReference]
        """
        return self._attendees

    @attendees.setter
    def attendees(self, attendees):
        """
        Sets the attendees of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :param attendees: The attendees of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :type: list[WemCoachingAppointmentTopicUserReference]
        """
        
        self._attendees = attendees

    @property
    def created_by(self):
        """
        Gets the created_by of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :return: The created_by of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :rtype: WemCoachingAppointmentTopicUserReference
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :param created_by: The created_by of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :type: WemCoachingAppointmentTopicUserReference
        """
        
        self._created_by = created_by

    @property
    def date_created(self):
        """
        Gets the date_created of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :return: The date_created of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :param date_created: The date_created of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def modified_by(self):
        """
        Gets the modified_by of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :return: The modified_by of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :rtype: WemCoachingAppointmentTopicUserReference
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :param modified_by: The modified_by of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :type: WemCoachingAppointmentTopicUserReference
        """
        
        self._modified_by = modified_by

    @property
    def date_modified(self):
        """
        Gets the date_modified of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :return: The date_modified of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :param date_modified: The date_modified of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def conversations(self):
        """
        Gets the conversations of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :return: The conversations of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :rtype: list[WemCoachingAppointmentTopicCoachingAppointmentConversation]
        """
        return self._conversations

    @conversations.setter
    def conversations(self, conversations):
        """
        Sets the conversations of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :param conversations: The conversations of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :type: list[WemCoachingAppointmentTopicCoachingAppointmentConversation]
        """
        
        self._conversations = conversations

    @property
    def documents(self):
        """
        Gets the documents of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :return: The documents of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :rtype: list[WemCoachingAppointmentTopicCoachingAppointmentDocument]
        """
        return self._documents

    @documents.setter
    def documents(self, documents):
        """
        Sets the documents of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :param documents: The documents of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :type: list[WemCoachingAppointmentTopicCoachingAppointmentDocument]
        """
        
        self._documents = documents

    @property
    def change_type(self):
        """
        Gets the change_type of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :return: The change_type of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :rtype: str
        """
        return self._change_type

    @change_type.setter
    def change_type(self, change_type):
        """
        Sets the change_type of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :param change_type: The change_type of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :type: str
        """
        allowed_values = ["Create", "Update", "Delete", "Invalidate"]
        if change_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for change_type -> " + change_type)
            self._change_type = "outdated_sdk_version"
        else:
            self._change_type = change_type

    @property
    def date_completed(self):
        """
        Gets the date_completed of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :return: The date_completed of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :rtype: datetime
        """
        return self._date_completed

    @date_completed.setter
    def date_completed(self, date_completed):
        """
        Sets the date_completed of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :param date_completed: The date_completed of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :type: datetime
        """
        
        self._date_completed = date_completed

    @property
    def external_links(self):
        """
        Gets the external_links of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :return: The external_links of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :rtype: list[WemCoachingAppointmentTopicCoachingAppointmentExternalLink]
        """
        return self._external_links

    @external_links.setter
    def external_links(self, external_links):
        """
        Sets the external_links of this WemCoachingAppointmentTopicCoachingAppointmentNotification.


        :param external_links: The external_links of this WemCoachingAppointmentTopicCoachingAppointmentNotification.
        :type: list[WemCoachingAppointmentTopicCoachingAppointmentExternalLink]
        """
        
        self._external_links = external_links

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class OrganizationFeatures(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        OrganizationFeatures - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'realtime_cic': 'bool',
            'purecloud': 'bool',
            'hipaa': 'bool',
            'uc_enabled': 'bool',
            'pci': 'bool',
            'purecloud_voice': 'bool',
            'xmpp_federation': 'bool',
            'chat': 'bool',
            'informal_photos': 'bool',
            'directory': 'bool',
            'contact_center': 'bool',
            'unified_communications': 'bool',
            'custserv': 'bool'
        }

        self.attribute_map = {
            'realtime_cic': 'realtimeCIC',
            'purecloud': 'purecloud',
            'hipaa': 'hipaa',
            'uc_enabled': 'ucEnabled',
            'pci': 'pci',
            'purecloud_voice': 'purecloudVoice',
            'xmpp_federation': 'xmppFederation',
            'chat': 'chat',
            'informal_photos': 'informalPhotos',
            'directory': 'directory',
            'contact_center': 'contactCenter',
            'unified_communications': 'unifiedCommunications',
            'custserv': 'custserv'
        }

        self._realtime_cic = None
        self._purecloud = None
        self._hipaa = None
        self._uc_enabled = None
        self._pci = None
        self._purecloud_voice = None
        self._xmpp_federation = None
        self._chat = None
        self._informal_photos = None
        self._directory = None
        self._contact_center = None
        self._unified_communications = None
        self._custserv = None

    @property
    def realtime_cic(self):
        """
        Gets the realtime_cic of this OrganizationFeatures.


        :return: The realtime_cic of this OrganizationFeatures.
        :rtype: bool
        """
        return self._realtime_cic

    @realtime_cic.setter
    def realtime_cic(self, realtime_cic):
        """
        Sets the realtime_cic of this OrganizationFeatures.


        :param realtime_cic: The realtime_cic of this OrganizationFeatures.
        :type: bool
        """
        
        self._realtime_cic = realtime_cic

    @property
    def purecloud(self):
        """
        Gets the purecloud of this OrganizationFeatures.


        :return: The purecloud of this OrganizationFeatures.
        :rtype: bool
        """
        return self._purecloud

    @purecloud.setter
    def purecloud(self, purecloud):
        """
        Sets the purecloud of this OrganizationFeatures.


        :param purecloud: The purecloud of this OrganizationFeatures.
        :type: bool
        """
        
        self._purecloud = purecloud

    @property
    def hipaa(self):
        """
        Gets the hipaa of this OrganizationFeatures.


        :return: The hipaa of this OrganizationFeatures.
        :rtype: bool
        """
        return self._hipaa

    @hipaa.setter
    def hipaa(self, hipaa):
        """
        Sets the hipaa of this OrganizationFeatures.


        :param hipaa: The hipaa of this OrganizationFeatures.
        :type: bool
        """
        
        self._hipaa = hipaa

    @property
    def uc_enabled(self):
        """
        Gets the uc_enabled of this OrganizationFeatures.


        :return: The uc_enabled of this OrganizationFeatures.
        :rtype: bool
        """
        return self._uc_enabled

    @uc_enabled.setter
    def uc_enabled(self, uc_enabled):
        """
        Sets the uc_enabled of this OrganizationFeatures.


        :param uc_enabled: The uc_enabled of this OrganizationFeatures.
        :type: bool
        """
        
        self._uc_enabled = uc_enabled

    @property
    def pci(self):
        """
        Gets the pci of this OrganizationFeatures.


        :return: The pci of this OrganizationFeatures.
        :rtype: bool
        """
        return self._pci

    @pci.setter
    def pci(self, pci):
        """
        Sets the pci of this OrganizationFeatures.


        :param pci: The pci of this OrganizationFeatures.
        :type: bool
        """
        
        self._pci = pci

    @property
    def purecloud_voice(self):
        """
        Gets the purecloud_voice of this OrganizationFeatures.


        :return: The purecloud_voice of this OrganizationFeatures.
        :rtype: bool
        """
        return self._purecloud_voice

    @purecloud_voice.setter
    def purecloud_voice(self, purecloud_voice):
        """
        Sets the purecloud_voice of this OrganizationFeatures.


        :param purecloud_voice: The purecloud_voice of this OrganizationFeatures.
        :type: bool
        """
        
        self._purecloud_voice = purecloud_voice

    @property
    def xmpp_federation(self):
        """
        Gets the xmpp_federation of this OrganizationFeatures.


        :return: The xmpp_federation of this OrganizationFeatures.
        :rtype: bool
        """
        return self._xmpp_federation

    @xmpp_federation.setter
    def xmpp_federation(self, xmpp_federation):
        """
        Sets the xmpp_federation of this OrganizationFeatures.


        :param xmpp_federation: The xmpp_federation of this OrganizationFeatures.
        :type: bool
        """
        
        self._xmpp_federation = xmpp_federation

    @property
    def chat(self):
        """
        Gets the chat of this OrganizationFeatures.


        :return: The chat of this OrganizationFeatures.
        :rtype: bool
        """
        return self._chat

    @chat.setter
    def chat(self, chat):
        """
        Sets the chat of this OrganizationFeatures.


        :param chat: The chat of this OrganizationFeatures.
        :type: bool
        """
        
        self._chat = chat

    @property
    def informal_photos(self):
        """
        Gets the informal_photos of this OrganizationFeatures.


        :return: The informal_photos of this OrganizationFeatures.
        :rtype: bool
        """
        return self._informal_photos

    @informal_photos.setter
    def informal_photos(self, informal_photos):
        """
        Sets the informal_photos of this OrganizationFeatures.


        :param informal_photos: The informal_photos of this OrganizationFeatures.
        :type: bool
        """
        
        self._informal_photos = informal_photos

    @property
    def directory(self):
        """
        Gets the directory of this OrganizationFeatures.


        :return: The directory of this OrganizationFeatures.
        :rtype: bool
        """
        return self._directory

    @directory.setter
    def directory(self, directory):
        """
        Sets the directory of this OrganizationFeatures.


        :param directory: The directory of this OrganizationFeatures.
        :type: bool
        """
        
        self._directory = directory

    @property
    def contact_center(self):
        """
        Gets the contact_center of this OrganizationFeatures.


        :return: The contact_center of this OrganizationFeatures.
        :rtype: bool
        """
        return self._contact_center

    @contact_center.setter
    def contact_center(self, contact_center):
        """
        Sets the contact_center of this OrganizationFeatures.


        :param contact_center: The contact_center of this OrganizationFeatures.
        :type: bool
        """
        
        self._contact_center = contact_center

    @property
    def unified_communications(self):
        """
        Gets the unified_communications of this OrganizationFeatures.


        :return: The unified_communications of this OrganizationFeatures.
        :rtype: bool
        """
        return self._unified_communications

    @unified_communications.setter
    def unified_communications(self, unified_communications):
        """
        Sets the unified_communications of this OrganizationFeatures.


        :param unified_communications: The unified_communications of this OrganizationFeatures.
        :type: bool
        """
        
        self._unified_communications = unified_communications

    @property
    def custserv(self):
        """
        Gets the custserv of this OrganizationFeatures.


        :return: The custserv of this OrganizationFeatures.
        :rtype: bool
        """
        return self._custserv

    @custserv.setter
    def custserv(self, custserv):
        """
        Sets the custserv of this OrganizationFeatures.


        :param custserv: The custserv of this OrganizationFeatures.
        :type: bool
        """
        
        self._custserv = custserv

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class MeteredAssignmentByAgent(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        MeteredAssignmentByAgent - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'evaluation_context_id': 'str',
            'evaluators': 'list[User]',
            'max_number_evaluations': 'int',
            'evaluation_form': 'EvaluationForm',
            'time_interval': 'TimeInterval',
            'time_zone': 'str'
        }

        self.attribute_map = {
            'evaluation_context_id': 'evaluationContextId',
            'evaluators': 'evaluators',
            'max_number_evaluations': 'maxNumberEvaluations',
            'evaluation_form': 'evaluationForm',
            'time_interval': 'timeInterval',
            'time_zone': 'timeZone'
        }

        self._evaluation_context_id = None
        self._evaluators = None
        self._max_number_evaluations = None
        self._evaluation_form = None
        self._time_interval = None
        self._time_zone = None

    @property
    def evaluation_context_id(self):
        """
        Gets the evaluation_context_id of this MeteredAssignmentByAgent.


        :return: The evaluation_context_id of this MeteredAssignmentByAgent.
        :rtype: str
        """
        return self._evaluation_context_id

    @evaluation_context_id.setter
    def evaluation_context_id(self, evaluation_context_id):
        """
        Sets the evaluation_context_id of this MeteredAssignmentByAgent.


        :param evaluation_context_id: The evaluation_context_id of this MeteredAssignmentByAgent.
        :type: str
        """
        
        self._evaluation_context_id = evaluation_context_id

    @property
    def evaluators(self):
        """
        Gets the evaluators of this MeteredAssignmentByAgent.


        :return: The evaluators of this MeteredAssignmentByAgent.
        :rtype: list[User]
        """
        return self._evaluators

    @evaluators.setter
    def evaluators(self, evaluators):
        """
        Sets the evaluators of this MeteredAssignmentByAgent.


        :param evaluators: The evaluators of this MeteredAssignmentByAgent.
        :type: list[User]
        """
        
        self._evaluators = evaluators

    @property
    def max_number_evaluations(self):
        """
        Gets the max_number_evaluations of this MeteredAssignmentByAgent.


        :return: The max_number_evaluations of this MeteredAssignmentByAgent.
        :rtype: int
        """
        return self._max_number_evaluations

    @max_number_evaluations.setter
    def max_number_evaluations(self, max_number_evaluations):
        """
        Sets the max_number_evaluations of this MeteredAssignmentByAgent.


        :param max_number_evaluations: The max_number_evaluations of this MeteredAssignmentByAgent.
        :type: int
        """
        
        self._max_number_evaluations = max_number_evaluations

    @property
    def evaluation_form(self):
        """
        Gets the evaluation_form of this MeteredAssignmentByAgent.


        :return: The evaluation_form of this MeteredAssignmentByAgent.
        :rtype: EvaluationForm
        """
        return self._evaluation_form

    @evaluation_form.setter
    def evaluation_form(self, evaluation_form):
        """
        Sets the evaluation_form of this MeteredAssignmentByAgent.


        :param evaluation_form: The evaluation_form of this MeteredAssignmentByAgent.
        :type: EvaluationForm
        """
        
        self._evaluation_form = evaluation_form

    @property
    def time_interval(self):
        """
        Gets the time_interval of this MeteredAssignmentByAgent.


        :return: The time_interval of this MeteredAssignmentByAgent.
        :rtype: TimeInterval
        """
        return self._time_interval

    @time_interval.setter
    def time_interval(self, time_interval):
        """
        Sets the time_interval of this MeteredAssignmentByAgent.


        :param time_interval: The time_interval of this MeteredAssignmentByAgent.
        :type: TimeInterval
        """
        
        self._time_interval = time_interval

    @property
    def time_zone(self):
        """
        Gets the time_zone of this MeteredAssignmentByAgent.


        :return: The time_zone of this MeteredAssignmentByAgent.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this MeteredAssignmentByAgent.


        :param time_zone: The time_zone of this MeteredAssignmentByAgent.
        :type: str
        """
        
        self._time_zone = time_zone

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class TrustorAuditQueryRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TrustorAuditQueryRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'trustor_organization_id': 'str',
            'trustee_user_ids': 'list[str]',
            'start_date': 'datetime',
            'end_date': 'datetime',
            'query_phrase': 'str',
            'facets': 'list[Facet]',
            'filters': 'list[Filter]'
        }

        self.attribute_map = {
            'trustor_organization_id': 'trustorOrganizationId',
            'trustee_user_ids': 'trusteeUserIds',
            'start_date': 'startDate',
            'end_date': 'endDate',
            'query_phrase': 'queryPhrase',
            'facets': 'facets',
            'filters': 'filters'
        }

        self._trustor_organization_id = None
        self._trustee_user_ids = None
        self._start_date = None
        self._end_date = None
        self._query_phrase = None
        self._facets = None
        self._filters = None

    @property
    def trustor_organization_id(self):
        """
        Gets the trustor_organization_id of this TrustorAuditQueryRequest.
        Limit returned audits to this trustor organizationId.

        :return: The trustor_organization_id of this TrustorAuditQueryRequest.
        :rtype: str
        """
        return self._trustor_organization_id

    @trustor_organization_id.setter
    def trustor_organization_id(self, trustor_organization_id):
        """
        Sets the trustor_organization_id of this TrustorAuditQueryRequest.
        Limit returned audits to this trustor organizationId.

        :param trustor_organization_id: The trustor_organization_id of this TrustorAuditQueryRequest.
        :type: str
        """
        
        self._trustor_organization_id = trustor_organization_id

    @property
    def trustee_user_ids(self):
        """
        Gets the trustee_user_ids of this TrustorAuditQueryRequest.
        Limit returned audits to these trustee userIds.

        :return: The trustee_user_ids of this TrustorAuditQueryRequest.
        :rtype: list[str]
        """
        return self._trustee_user_ids

    @trustee_user_ids.setter
    def trustee_user_ids(self, trustee_user_ids):
        """
        Sets the trustee_user_ids of this TrustorAuditQueryRequest.
        Limit returned audits to these trustee userIds.

        :param trustee_user_ids: The trustee_user_ids of this TrustorAuditQueryRequest.
        :type: list[str]
        """
        
        self._trustee_user_ids = trustee_user_ids

    @property
    def start_date(self):
        """
        Gets the start_date of this TrustorAuditQueryRequest.
        Starting date/time for the audit search. ISO-8601 formatted date-time, UTC.

        :return: The start_date of this TrustorAuditQueryRequest.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this TrustorAuditQueryRequest.
        Starting date/time for the audit search. ISO-8601 formatted date-time, UTC.

        :param start_date: The start_date of this TrustorAuditQueryRequest.
        :type: datetime
        """
        
        self._start_date = start_date

    @property
    def end_date(self):
        """
        Gets the end_date of this TrustorAuditQueryRequest.
        Ending date/time for the audit search. ISO-8601 formatted date-time, UTC.

        :return: The end_date of this TrustorAuditQueryRequest.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this TrustorAuditQueryRequest.
        Ending date/time for the audit search. ISO-8601 formatted date-time, UTC.

        :param end_date: The end_date of this TrustorAuditQueryRequest.
        :type: datetime
        """
        
        self._end_date = end_date

    @property
    def query_phrase(self):
        """
        Gets the query_phrase of this TrustorAuditQueryRequest.
        Word or phrase to look for in audit bodies.

        :return: The query_phrase of this TrustorAuditQueryRequest.
        :rtype: str
        """
        return self._query_phrase

    @query_phrase.setter
    def query_phrase(self, query_phrase):
        """
        Sets the query_phrase of this TrustorAuditQueryRequest.
        Word or phrase to look for in audit bodies.

        :param query_phrase: The query_phrase of this TrustorAuditQueryRequest.
        :type: str
        """
        
        self._query_phrase = query_phrase

    @property
    def facets(self):
        """
        Gets the facets of this TrustorAuditQueryRequest.
        Facet information to be returned with the query results.

        :return: The facets of this TrustorAuditQueryRequest.
        :rtype: list[Facet]
        """
        return self._facets

    @facets.setter
    def facets(self, facets):
        """
        Sets the facets of this TrustorAuditQueryRequest.
        Facet information to be returned with the query results.

        :param facets: The facets of this TrustorAuditQueryRequest.
        :type: list[Facet]
        """
        
        self._facets = facets

    @property
    def filters(self):
        """
        Gets the filters of this TrustorAuditQueryRequest.
        Additional custom filters to be applied to the query.

        :return: The filters of this TrustorAuditQueryRequest.
        :rtype: list[Filter]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """
        Sets the filters of this TrustorAuditQueryRequest.
        Additional custom filters to be applied to the query.

        :param filters: The filters of this TrustorAuditQueryRequest.
        :type: list[Filter]
        """
        
        self._filters = filters

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WorkPlanShift(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WorkPlanShift - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'days': 'SetWrapperDayOfWeek',
            'flexible_start_time': 'bool',
            'exact_start_time_minutes_from_midnight': 'int',
            'earliest_start_time_minutes_from_midnight': 'int',
            'latest_start_time_minutes_from_midnight': 'int',
            'constrain_stop_time': 'bool',
            'constrain_latest_stop_time': 'bool',
            'latest_stop_time_minutes_from_midnight': 'int',
            'constrain_earliest_stop_time': 'bool',
            'earliest_stop_time_minutes_from_midnight': 'int',
            'start_increment_minutes': 'int',
            'flexible_paid_time': 'bool',
            'exact_paid_time_minutes': 'int',
            'minimum_paid_time_minutes': 'int',
            'maximum_paid_time_minutes': 'int',
            'constrain_contiguous_work_time': 'bool',
            'minimum_contiguous_work_time_minutes': 'int',
            'maximum_contiguous_work_time_minutes': 'int',
            'activities': 'list[WorkPlanActivity]',
            'id': 'str',
            'delete': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'days': 'days',
            'flexible_start_time': 'flexibleStartTime',
            'exact_start_time_minutes_from_midnight': 'exactStartTimeMinutesFromMidnight',
            'earliest_start_time_minutes_from_midnight': 'earliestStartTimeMinutesFromMidnight',
            'latest_start_time_minutes_from_midnight': 'latestStartTimeMinutesFromMidnight',
            'constrain_stop_time': 'constrainStopTime',
            'constrain_latest_stop_time': 'constrainLatestStopTime',
            'latest_stop_time_minutes_from_midnight': 'latestStopTimeMinutesFromMidnight',
            'constrain_earliest_stop_time': 'constrainEarliestStopTime',
            'earliest_stop_time_minutes_from_midnight': 'earliestStopTimeMinutesFromMidnight',
            'start_increment_minutes': 'startIncrementMinutes',
            'flexible_paid_time': 'flexiblePaidTime',
            'exact_paid_time_minutes': 'exactPaidTimeMinutes',
            'minimum_paid_time_minutes': 'minimumPaidTimeMinutes',
            'maximum_paid_time_minutes': 'maximumPaidTimeMinutes',
            'constrain_contiguous_work_time': 'constrainContiguousWorkTime',
            'minimum_contiguous_work_time_minutes': 'minimumContiguousWorkTimeMinutes',
            'maximum_contiguous_work_time_minutes': 'maximumContiguousWorkTimeMinutes',
            'activities': 'activities',
            'id': 'id',
            'delete': 'delete'
        }

        self._name = None
        self._days = None
        self._flexible_start_time = None
        self._exact_start_time_minutes_from_midnight = None
        self._earliest_start_time_minutes_from_midnight = None
        self._latest_start_time_minutes_from_midnight = None
        self._constrain_stop_time = None
        self._constrain_latest_stop_time = None
        self._latest_stop_time_minutes_from_midnight = None
        self._constrain_earliest_stop_time = None
        self._earliest_stop_time_minutes_from_midnight = None
        self._start_increment_minutes = None
        self._flexible_paid_time = None
        self._exact_paid_time_minutes = None
        self._minimum_paid_time_minutes = None
        self._maximum_paid_time_minutes = None
        self._constrain_contiguous_work_time = None
        self._minimum_contiguous_work_time_minutes = None
        self._maximum_contiguous_work_time_minutes = None
        self._activities = None
        self._id = None
        self._delete = None

    @property
    def name(self):
        """
        Gets the name of this WorkPlanShift.
        Name of the shift

        :return: The name of this WorkPlanShift.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this WorkPlanShift.
        Name of the shift

        :param name: The name of this WorkPlanShift.
        :type: str
        """
        
        self._name = name

    @property
    def days(self):
        """
        Gets the days of this WorkPlanShift.
        Days of the week applicable for this shift

        :return: The days of this WorkPlanShift.
        :rtype: SetWrapperDayOfWeek
        """
        return self._days

    @days.setter
    def days(self, days):
        """
        Sets the days of this WorkPlanShift.
        Days of the week applicable for this shift

        :param days: The days of this WorkPlanShift.
        :type: SetWrapperDayOfWeek
        """
        
        self._days = days

    @property
    def flexible_start_time(self):
        """
        Gets the flexible_start_time of this WorkPlanShift.
        Whether the start time of the shift is flexible

        :return: The flexible_start_time of this WorkPlanShift.
        :rtype: bool
        """
        return self._flexible_start_time

    @flexible_start_time.setter
    def flexible_start_time(self, flexible_start_time):
        """
        Sets the flexible_start_time of this WorkPlanShift.
        Whether the start time of the shift is flexible

        :param flexible_start_time: The flexible_start_time of this WorkPlanShift.
        :type: bool
        """
        
        self._flexible_start_time = flexible_start_time

    @property
    def exact_start_time_minutes_from_midnight(self):
        """
        Gets the exact_start_time_minutes_from_midnight of this WorkPlanShift.
        Exact start time of the shift defined as offset minutes from midnight. Used if flexibleStartTime == false

        :return: The exact_start_time_minutes_from_midnight of this WorkPlanShift.
        :rtype: int
        """
        return self._exact_start_time_minutes_from_midnight

    @exact_start_time_minutes_from_midnight.setter
    def exact_start_time_minutes_from_midnight(self, exact_start_time_minutes_from_midnight):
        """
        Sets the exact_start_time_minutes_from_midnight of this WorkPlanShift.
        Exact start time of the shift defined as offset minutes from midnight. Used if flexibleStartTime == false

        :param exact_start_time_minutes_from_midnight: The exact_start_time_minutes_from_midnight of this WorkPlanShift.
        :type: int
        """
        
        self._exact_start_time_minutes_from_midnight = exact_start_time_minutes_from_midnight

    @property
    def earliest_start_time_minutes_from_midnight(self):
        """
        Gets the earliest_start_time_minutes_from_midnight of this WorkPlanShift.
        Earliest start time of the shift defined as offset minutes from midnight. Used if flexibleStartTime == true

        :return: The earliest_start_time_minutes_from_midnight of this WorkPlanShift.
        :rtype: int
        """
        return self._earliest_start_time_minutes_from_midnight

    @earliest_start_time_minutes_from_midnight.setter
    def earliest_start_time_minutes_from_midnight(self, earliest_start_time_minutes_from_midnight):
        """
        Sets the earliest_start_time_minutes_from_midnight of this WorkPlanShift.
        Earliest start time of the shift defined as offset minutes from midnight. Used if flexibleStartTime == true

        :param earliest_start_time_minutes_from_midnight: The earliest_start_time_minutes_from_midnight of this WorkPlanShift.
        :type: int
        """
        
        self._earliest_start_time_minutes_from_midnight = earliest_start_time_minutes_from_midnight

    @property
    def latest_start_time_minutes_from_midnight(self):
        """
        Gets the latest_start_time_minutes_from_midnight of this WorkPlanShift.
        Latest start time of the shift defined as offset minutes from midnight. Used if flexibleStartTime == true

        :return: The latest_start_time_minutes_from_midnight of this WorkPlanShift.
        :rtype: int
        """
        return self._latest_start_time_minutes_from_midnight

    @latest_start_time_minutes_from_midnight.setter
    def latest_start_time_minutes_from_midnight(self, latest_start_time_minutes_from_midnight):
        """
        Sets the latest_start_time_minutes_from_midnight of this WorkPlanShift.
        Latest start time of the shift defined as offset minutes from midnight. Used if flexibleStartTime == true

        :param latest_start_time_minutes_from_midnight: The latest_start_time_minutes_from_midnight of this WorkPlanShift.
        :type: int
        """
        
        self._latest_start_time_minutes_from_midnight = latest_start_time_minutes_from_midnight

    @property
    def constrain_stop_time(self):
        """
        Gets the constrain_stop_time of this WorkPlanShift.
        Whether the latest stop time constraint for the shift is enabled.  Deprecated, use constrainLatestStopTime instead

        :return: The constrain_stop_time of this WorkPlanShift.
        :rtype: bool
        """
        return self._constrain_stop_time

    @constrain_stop_time.setter
    def constrain_stop_time(self, constrain_stop_time):
        """
        Sets the constrain_stop_time of this WorkPlanShift.
        Whether the latest stop time constraint for the shift is enabled.  Deprecated, use constrainLatestStopTime instead

        :param constrain_stop_time: The constrain_stop_time of this WorkPlanShift.
        :type: bool
        """
        
        self._constrain_stop_time = constrain_stop_time

    @property
    def constrain_latest_stop_time(self):
        """
        Gets the constrain_latest_stop_time of this WorkPlanShift.
        Whether the latest stop time constraint for the shift is enabled

        :return: The constrain_latest_stop_time of this WorkPlanShift.
        :rtype: bool
        """
        return self._constrain_latest_stop_time

    @constrain_latest_stop_time.setter
    def constrain_latest_stop_time(self, constrain_latest_stop_time):
        """
        Sets the constrain_latest_stop_time of this WorkPlanShift.
        Whether the latest stop time constraint for the shift is enabled

        :param constrain_latest_stop_time: The constrain_latest_stop_time of this WorkPlanShift.
        :type: bool
        """
        
        self._constrain_latest_stop_time = constrain_latest_stop_time

    @property
    def latest_stop_time_minutes_from_midnight(self):
        """
        Gets the latest_stop_time_minutes_from_midnight of this WorkPlanShift.
        Latest stop time of the shift defined as offset minutes from midnight. Used if constrainStopTime == true

        :return: The latest_stop_time_minutes_from_midnight of this WorkPlanShift.
        :rtype: int
        """
        return self._latest_stop_time_minutes_from_midnight

    @latest_stop_time_minutes_from_midnight.setter
    def latest_stop_time_minutes_from_midnight(self, latest_stop_time_minutes_from_midnight):
        """
        Sets the latest_stop_time_minutes_from_midnight of this WorkPlanShift.
        Latest stop time of the shift defined as offset minutes from midnight. Used if constrainStopTime == true

        :param latest_stop_time_minutes_from_midnight: The latest_stop_time_minutes_from_midnight of this WorkPlanShift.
        :type: int
        """
        
        self._latest_stop_time_minutes_from_midnight = latest_stop_time_minutes_from_midnight

    @property
    def constrain_earliest_stop_time(self):
        """
        Gets the constrain_earliest_stop_time of this WorkPlanShift.
        Whether the earliest stop time constraint for the shift is enabled

        :return: The constrain_earliest_stop_time of this WorkPlanShift.
        :rtype: bool
        """
        return self._constrain_earliest_stop_time

    @constrain_earliest_stop_time.setter
    def constrain_earliest_stop_time(self, constrain_earliest_stop_time):
        """
        Sets the constrain_earliest_stop_time of this WorkPlanShift.
        Whether the earliest stop time constraint for the shift is enabled

        :param constrain_earliest_stop_time: The constrain_earliest_stop_time of this WorkPlanShift.
        :type: bool
        """
        
        self._constrain_earliest_stop_time = constrain_earliest_stop_time

    @property
    def earliest_stop_time_minutes_from_midnight(self):
        """
        Gets the earliest_stop_time_minutes_from_midnight of this WorkPlanShift.
        This is the earliest time a shift can end

        :return: The earliest_stop_time_minutes_from_midnight of this WorkPlanShift.
        :rtype: int
        """
        return self._earliest_stop_time_minutes_from_midnight

    @earliest_stop_time_minutes_from_midnight.setter
    def earliest_stop_time_minutes_from_midnight(self, earliest_stop_time_minutes_from_midnight):
        """
        Sets the earliest_stop_time_minutes_from_midnight of this WorkPlanShift.
        This is the earliest time a shift can end

        :param earliest_stop_time_minutes_from_midnight: The earliest_stop_time_minutes_from_midnight of this WorkPlanShift.
        :type: int
        """
        
        self._earliest_stop_time_minutes_from_midnight = earliest_stop_time_minutes_from_midnight

    @property
    def start_increment_minutes(self):
        """
        Gets the start_increment_minutes of this WorkPlanShift.
        Increment in offset minutes that would contribute to different possible start times for the shift. Used if flexibleStartTime == true

        :return: The start_increment_minutes of this WorkPlanShift.
        :rtype: int
        """
        return self._start_increment_minutes

    @start_increment_minutes.setter
    def start_increment_minutes(self, start_increment_minutes):
        """
        Sets the start_increment_minutes of this WorkPlanShift.
        Increment in offset minutes that would contribute to different possible start times for the shift. Used if flexibleStartTime == true

        :param start_increment_minutes: The start_increment_minutes of this WorkPlanShift.
        :type: int
        """
        
        self._start_increment_minutes = start_increment_minutes

    @property
    def flexible_paid_time(self):
        """
        Gets the flexible_paid_time of this WorkPlanShift.
        Whether the paid time setting for the shift is flexible

        :return: The flexible_paid_time of this WorkPlanShift.
        :rtype: bool
        """
        return self._flexible_paid_time

    @flexible_paid_time.setter
    def flexible_paid_time(self, flexible_paid_time):
        """
        Sets the flexible_paid_time of this WorkPlanShift.
        Whether the paid time setting for the shift is flexible

        :param flexible_paid_time: The flexible_paid_time of this WorkPlanShift.
        :type: bool
        """
        
        self._flexible_paid_time = flexible_paid_time

    @property
    def exact_paid_time_minutes(self):
        """
        Gets the exact_paid_time_minutes of this WorkPlanShift.
        Exact paid time in minutes configured for the shift. Used if flexiblePaidTime == false

        :return: The exact_paid_time_minutes of this WorkPlanShift.
        :rtype: int
        """
        return self._exact_paid_time_minutes

    @exact_paid_time_minutes.setter
    def exact_paid_time_minutes(self, exact_paid_time_minutes):
        """
        Sets the exact_paid_time_minutes of this WorkPlanShift.
        Exact paid time in minutes configured for the shift. Used if flexiblePaidTime == false

        :param exact_paid_time_minutes: The exact_paid_time_minutes of this WorkPlanShift.
        :type: int
        """
        
        self._exact_paid_time_minutes = exact_paid_time_minutes

    @property
    def minimum_paid_time_minutes(self):
        """
        Gets the minimum_paid_time_minutes of this WorkPlanShift.
        Minimum paid time in minutes configured for the shift. Used if flexiblePaidTime == true

        :return: The minimum_paid_time_minutes of this WorkPlanShift.
        :rtype: int
        """
        return self._minimum_paid_time_minutes

    @minimum_paid_time_minutes.setter
    def minimum_paid_time_minutes(self, minimum_paid_time_minutes):
        """
        Sets the minimum_paid_time_minutes of this WorkPlanShift.
        Minimum paid time in minutes configured for the shift. Used if flexiblePaidTime == true

        :param minimum_paid_time_minutes: The minimum_paid_time_minutes of this WorkPlanShift.
        :type: int
        """
        
        self._minimum_paid_time_minutes = minimum_paid_time_minutes

    @property
    def maximum_paid_time_minutes(self):
        """
        Gets the maximum_paid_time_minutes of this WorkPlanShift.
        Maximum paid time in minutes configured for the shift. Used if flexiblePaidTime == true

        :return: The maximum_paid_time_minutes of this WorkPlanShift.
        :rtype: int
        """
        return self._maximum_paid_time_minutes

    @maximum_paid_time_minutes.setter
    def maximum_paid_time_minutes(self, maximum_paid_time_minutes):
        """
        Sets the maximum_paid_time_minutes of this WorkPlanShift.
        Maximum paid time in minutes configured for the shift. Used if flexiblePaidTime == true

        :param maximum_paid_time_minutes: The maximum_paid_time_minutes of this WorkPlanShift.
        :type: int
        """
        
        self._maximum_paid_time_minutes = maximum_paid_time_minutes

    @property
    def constrain_contiguous_work_time(self):
        """
        Gets the constrain_contiguous_work_time of this WorkPlanShift.
        Whether the contiguous time constraint for the shift is enabled

        :return: The constrain_contiguous_work_time of this WorkPlanShift.
        :rtype: bool
        """
        return self._constrain_contiguous_work_time

    @constrain_contiguous_work_time.setter
    def constrain_contiguous_work_time(self, constrain_contiguous_work_time):
        """
        Sets the constrain_contiguous_work_time of this WorkPlanShift.
        Whether the contiguous time constraint for the shift is enabled

        :param constrain_contiguous_work_time: The constrain_contiguous_work_time of this WorkPlanShift.
        :type: bool
        """
        
        self._constrain_contiguous_work_time = constrain_contiguous_work_time

    @property
    def minimum_contiguous_work_time_minutes(self):
        """
        Gets the minimum_contiguous_work_time_minutes of this WorkPlanShift.
        Minimum contiguous time in minutes configured for the shift. Used if constrainContiguousWorkTime == true

        :return: The minimum_contiguous_work_time_minutes of this WorkPlanShift.
        :rtype: int
        """
        return self._minimum_contiguous_work_time_minutes

    @minimum_contiguous_work_time_minutes.setter
    def minimum_contiguous_work_time_minutes(self, minimum_contiguous_work_time_minutes):
        """
        Sets the minimum_contiguous_work_time_minutes of this WorkPlanShift.
        Minimum contiguous time in minutes configured for the shift. Used if constrainContiguousWorkTime == true

        :param minimum_contiguous_work_time_minutes: The minimum_contiguous_work_time_minutes of this WorkPlanShift.
        :type: int
        """
        
        self._minimum_contiguous_work_time_minutes = minimum_contiguous_work_time_minutes

    @property
    def maximum_contiguous_work_time_minutes(self):
        """
        Gets the maximum_contiguous_work_time_minutes of this WorkPlanShift.
        Maximum contiguous time in minutes configured for the shift. Used if constrainContiguousWorkTime == true

        :return: The maximum_contiguous_work_time_minutes of this WorkPlanShift.
        :rtype: int
        """
        return self._maximum_contiguous_work_time_minutes

    @maximum_contiguous_work_time_minutes.setter
    def maximum_contiguous_work_time_minutes(self, maximum_contiguous_work_time_minutes):
        """
        Sets the maximum_contiguous_work_time_minutes of this WorkPlanShift.
        Maximum contiguous time in minutes configured for the shift. Used if constrainContiguousWorkTime == true

        :param maximum_contiguous_work_time_minutes: The maximum_contiguous_work_time_minutes of this WorkPlanShift.
        :type: int
        """
        
        self._maximum_contiguous_work_time_minutes = maximum_contiguous_work_time_minutes

    @property
    def activities(self):
        """
        Gets the activities of this WorkPlanShift.
        Activities configured for this shift

        :return: The activities of this WorkPlanShift.
        :rtype: list[WorkPlanActivity]
        """
        return self._activities

    @activities.setter
    def activities(self, activities):
        """
        Sets the activities of this WorkPlanShift.
        Activities configured for this shift

        :param activities: The activities of this WorkPlanShift.
        :type: list[WorkPlanActivity]
        """
        
        self._activities = activities

    @property
    def id(self):
        """
        Gets the id of this WorkPlanShift.
        ID of the shift. This is required only for the case of updating an existing shift

        :return: The id of this WorkPlanShift.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WorkPlanShift.
        ID of the shift. This is required only for the case of updating an existing shift

        :param id: The id of this WorkPlanShift.
        :type: str
        """
        
        self._id = id

    @property
    def delete(self):
        """
        Gets the delete of this WorkPlanShift.
        If marked true for updating an existing shift, the shift will be permanently deleted

        :return: The delete of this WorkPlanShift.
        :rtype: bool
        """
        return self._delete

    @delete.setter
    def delete(self, delete):
        """
        Sets the delete of this WorkPlanShift.
        If marked true for updating an existing shift, the shift will be permanently deleted

        :param delete: The delete of this WorkPlanShift.
        :type: bool
        """
        
        self._delete = delete

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class LexBotAlias(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        LexBotAlias - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'bot': 'LexBot',
            'bot_version': 'str',
            'status': 'str',
            'failure_reason': 'str',
            'language': 'str',
            'intents': 'list[LexIntent]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'bot': 'bot',
            'bot_version': 'botVersion',
            'status': 'status',
            'failure_reason': 'failureReason',
            'language': 'language',
            'intents': 'intents',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._bot = None
        self._bot_version = None
        self._status = None
        self._failure_reason = None
        self._language = None
        self._intents = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this LexBotAlias.
        The globally unique identifier for the object.

        :return: The id of this LexBotAlias.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this LexBotAlias.
        The globally unique identifier for the object.

        :param id: The id of this LexBotAlias.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this LexBotAlias.


        :return: The name of this LexBotAlias.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LexBotAlias.


        :param name: The name of this LexBotAlias.
        :type: str
        """
        
        self._name = name

    @property
    def bot(self):
        """
        Gets the bot of this LexBotAlias.
        The Lex bot this is an alias for

        :return: The bot of this LexBotAlias.
        :rtype: LexBot
        """
        return self._bot

    @bot.setter
    def bot(self, bot):
        """
        Sets the bot of this LexBotAlias.
        The Lex bot this is an alias for

        :param bot: The bot of this LexBotAlias.
        :type: LexBot
        """
        
        self._bot = bot

    @property
    def bot_version(self):
        """
        Gets the bot_version of this LexBotAlias.
        The version of the Lex bot this alias points at

        :return: The bot_version of this LexBotAlias.
        :rtype: str
        """
        return self._bot_version

    @bot_version.setter
    def bot_version(self, bot_version):
        """
        Sets the bot_version of this LexBotAlias.
        The version of the Lex bot this alias points at

        :param bot_version: The bot_version of this LexBotAlias.
        :type: str
        """
        
        self._bot_version = bot_version

    @property
    def status(self):
        """
        Gets the status of this LexBotAlias.
        The status of the Lex bot alias

        :return: The status of this LexBotAlias.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this LexBotAlias.
        The status of the Lex bot alias

        :param status: The status of this LexBotAlias.
        :type: str
        """
        allowed_values = ["BUILDING", "READY", "FAILED", "NOT_BUILT"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def failure_reason(self):
        """
        Gets the failure_reason of this LexBotAlias.
        If the status is FAILED, Amazon Lex explains why it failed to build the bot

        :return: The failure_reason of this LexBotAlias.
        :rtype: str
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """
        Sets the failure_reason of this LexBotAlias.
        If the status is FAILED, Amazon Lex explains why it failed to build the bot

        :param failure_reason: The failure_reason of this LexBotAlias.
        :type: str
        """
        
        self._failure_reason = failure_reason

    @property
    def language(self):
        """
        Gets the language of this LexBotAlias.
        The target language of the Lex bot

        :return: The language of this LexBotAlias.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        Sets the language of this LexBotAlias.
        The target language of the Lex bot

        :param language: The language of this LexBotAlias.
        :type: str
        """
        allowed_values = ["en-US"]
        if language.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for language -> " + language)
            self._language = "outdated_sdk_version"
        else:
            self._language = language

    @property
    def intents(self):
        """
        Gets the intents of this LexBotAlias.
        An array of Intents associated with this bot alias

        :return: The intents of this LexBotAlias.
        :rtype: list[LexIntent]
        """
        return self._intents

    @intents.setter
    def intents(self, intents):
        """
        Sets the intents of this LexBotAlias.
        An array of Intents associated with this bot alias

        :param intents: The intents of this LexBotAlias.
        :type: list[LexIntent]
        """
        
        self._intents = intents

    @property
    def self_uri(self):
        """
        Gets the self_uri of this LexBotAlias.
        The URI for this object

        :return: The self_uri of this LexBotAlias.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this LexBotAlias.
        The URI for this object

        :param self_uri: The self_uri of this LexBotAlias.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class VoicemailMessagesTopicVoicemailMessage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        VoicemailMessagesTopicVoicemailMessage - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'read': 'bool',
            'audio_recording_duration_seconds': 'int',
            'audio_recording_size_bytes': 'int',
            'created_date': 'datetime',
            'modified_date': 'datetime',
            'caller_address': 'str',
            'caller_name': 'str',
            'action': 'str',
            'note': 'str',
            'deleted': 'bool',
            'modified_by_user_id': 'str',
            'copied_to': 'list[VoicemailMessagesTopicVoicemailCopyRecord]',
            'copied_from': 'VoicemailMessagesTopicVoicemailCopyRecord'
        }

        self.attribute_map = {
            'id': 'id',
            'read': 'read',
            'audio_recording_duration_seconds': 'audioRecordingDurationSeconds',
            'audio_recording_size_bytes': 'audioRecordingSizeBytes',
            'created_date': 'createdDate',
            'modified_date': 'modifiedDate',
            'caller_address': 'callerAddress',
            'caller_name': 'callerName',
            'action': 'action',
            'note': 'note',
            'deleted': 'deleted',
            'modified_by_user_id': 'modifiedByUserId',
            'copied_to': 'copiedTo',
            'copied_from': 'copiedFrom'
        }

        self._id = None
        self._read = None
        self._audio_recording_duration_seconds = None
        self._audio_recording_size_bytes = None
        self._created_date = None
        self._modified_date = None
        self._caller_address = None
        self._caller_name = None
        self._action = None
        self._note = None
        self._deleted = None
        self._modified_by_user_id = None
        self._copied_to = None
        self._copied_from = None

    @property
    def id(self):
        """
        Gets the id of this VoicemailMessagesTopicVoicemailMessage.


        :return: The id of this VoicemailMessagesTopicVoicemailMessage.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VoicemailMessagesTopicVoicemailMessage.


        :param id: The id of this VoicemailMessagesTopicVoicemailMessage.
        :type: str
        """
        
        self._id = id

    @property
    def read(self):
        """
        Gets the read of this VoicemailMessagesTopicVoicemailMessage.


        :return: The read of this VoicemailMessagesTopicVoicemailMessage.
        :rtype: bool
        """
        return self._read

    @read.setter
    def read(self, read):
        """
        Sets the read of this VoicemailMessagesTopicVoicemailMessage.


        :param read: The read of this VoicemailMessagesTopicVoicemailMessage.
        :type: bool
        """
        
        self._read = read

    @property
    def audio_recording_duration_seconds(self):
        """
        Gets the audio_recording_duration_seconds of this VoicemailMessagesTopicVoicemailMessage.


        :return: The audio_recording_duration_seconds of this VoicemailMessagesTopicVoicemailMessage.
        :rtype: int
        """
        return self._audio_recording_duration_seconds

    @audio_recording_duration_seconds.setter
    def audio_recording_duration_seconds(self, audio_recording_duration_seconds):
        """
        Sets the audio_recording_duration_seconds of this VoicemailMessagesTopicVoicemailMessage.


        :param audio_recording_duration_seconds: The audio_recording_duration_seconds of this VoicemailMessagesTopicVoicemailMessage.
        :type: int
        """
        
        self._audio_recording_duration_seconds = audio_recording_duration_seconds

    @property
    def audio_recording_size_bytes(self):
        """
        Gets the audio_recording_size_bytes of this VoicemailMessagesTopicVoicemailMessage.


        :return: The audio_recording_size_bytes of this VoicemailMessagesTopicVoicemailMessage.
        :rtype: int
        """
        return self._audio_recording_size_bytes

    @audio_recording_size_bytes.setter
    def audio_recording_size_bytes(self, audio_recording_size_bytes):
        """
        Sets the audio_recording_size_bytes of this VoicemailMessagesTopicVoicemailMessage.


        :param audio_recording_size_bytes: The audio_recording_size_bytes of this VoicemailMessagesTopicVoicemailMessage.
        :type: int
        """
        
        self._audio_recording_size_bytes = audio_recording_size_bytes

    @property
    def created_date(self):
        """
        Gets the created_date of this VoicemailMessagesTopicVoicemailMessage.


        :return: The created_date of this VoicemailMessagesTopicVoicemailMessage.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this VoicemailMessagesTopicVoicemailMessage.


        :param created_date: The created_date of this VoicemailMessagesTopicVoicemailMessage.
        :type: datetime
        """
        
        self._created_date = created_date

    @property
    def modified_date(self):
        """
        Gets the modified_date of this VoicemailMessagesTopicVoicemailMessage.


        :return: The modified_date of this VoicemailMessagesTopicVoicemailMessage.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this VoicemailMessagesTopicVoicemailMessage.


        :param modified_date: The modified_date of this VoicemailMessagesTopicVoicemailMessage.
        :type: datetime
        """
        
        self._modified_date = modified_date

    @property
    def caller_address(self):
        """
        Gets the caller_address of this VoicemailMessagesTopicVoicemailMessage.


        :return: The caller_address of this VoicemailMessagesTopicVoicemailMessage.
        :rtype: str
        """
        return self._caller_address

    @caller_address.setter
    def caller_address(self, caller_address):
        """
        Sets the caller_address of this VoicemailMessagesTopicVoicemailMessage.


        :param caller_address: The caller_address of this VoicemailMessagesTopicVoicemailMessage.
        :type: str
        """
        
        self._caller_address = caller_address

    @property
    def caller_name(self):
        """
        Gets the caller_name of this VoicemailMessagesTopicVoicemailMessage.


        :return: The caller_name of this VoicemailMessagesTopicVoicemailMessage.
        :rtype: str
        """
        return self._caller_name

    @caller_name.setter
    def caller_name(self, caller_name):
        """
        Sets the caller_name of this VoicemailMessagesTopicVoicemailMessage.


        :param caller_name: The caller_name of this VoicemailMessagesTopicVoicemailMessage.
        :type: str
        """
        
        self._caller_name = caller_name

    @property
    def action(self):
        """
        Gets the action of this VoicemailMessagesTopicVoicemailMessage.


        :return: The action of this VoicemailMessagesTopicVoicemailMessage.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this VoicemailMessagesTopicVoicemailMessage.


        :param action: The action of this VoicemailMessagesTopicVoicemailMessage.
        :type: str
        """
        
        self._action = action

    @property
    def note(self):
        """
        Gets the note of this VoicemailMessagesTopicVoicemailMessage.


        :return: The note of this VoicemailMessagesTopicVoicemailMessage.
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """
        Sets the note of this VoicemailMessagesTopicVoicemailMessage.


        :param note: The note of this VoicemailMessagesTopicVoicemailMessage.
        :type: str
        """
        
        self._note = note

    @property
    def deleted(self):
        """
        Gets the deleted of this VoicemailMessagesTopicVoicemailMessage.


        :return: The deleted of this VoicemailMessagesTopicVoicemailMessage.
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """
        Sets the deleted of this VoicemailMessagesTopicVoicemailMessage.


        :param deleted: The deleted of this VoicemailMessagesTopicVoicemailMessage.
        :type: bool
        """
        
        self._deleted = deleted

    @property
    def modified_by_user_id(self):
        """
        Gets the modified_by_user_id of this VoicemailMessagesTopicVoicemailMessage.


        :return: The modified_by_user_id of this VoicemailMessagesTopicVoicemailMessage.
        :rtype: str
        """
        return self._modified_by_user_id

    @modified_by_user_id.setter
    def modified_by_user_id(self, modified_by_user_id):
        """
        Sets the modified_by_user_id of this VoicemailMessagesTopicVoicemailMessage.


        :param modified_by_user_id: The modified_by_user_id of this VoicemailMessagesTopicVoicemailMessage.
        :type: str
        """
        
        self._modified_by_user_id = modified_by_user_id

    @property
    def copied_to(self):
        """
        Gets the copied_to of this VoicemailMessagesTopicVoicemailMessage.


        :return: The copied_to of this VoicemailMessagesTopicVoicemailMessage.
        :rtype: list[VoicemailMessagesTopicVoicemailCopyRecord]
        """
        return self._copied_to

    @copied_to.setter
    def copied_to(self, copied_to):
        """
        Sets the copied_to of this VoicemailMessagesTopicVoicemailMessage.


        :param copied_to: The copied_to of this VoicemailMessagesTopicVoicemailMessage.
        :type: list[VoicemailMessagesTopicVoicemailCopyRecord]
        """
        
        self._copied_to = copied_to

    @property
    def copied_from(self):
        """
        Gets the copied_from of this VoicemailMessagesTopicVoicemailMessage.


        :return: The copied_from of this VoicemailMessagesTopicVoicemailMessage.
        :rtype: VoicemailMessagesTopicVoicemailCopyRecord
        """
        return self._copied_from

    @copied_from.setter
    def copied_from(self, copied_from):
        """
        Sets the copied_from of this VoicemailMessagesTopicVoicemailMessage.


        :param copied_from: The copied_from of this VoicemailMessagesTopicVoicemailMessage.
        :type: VoicemailMessagesTopicVoicemailCopyRecord
        """
        
        self._copied_from = copied_from

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CreateWebChatConversationRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CreateWebChatConversationRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'organization_id': 'str',
            'deployment_id': 'str',
            'routing_target': 'WebChatRoutingTarget',
            'member_info': 'GuestMemberInfo',
            'member_auth_token': 'str',
            'journey_context': 'JourneyContext'
        }

        self.attribute_map = {
            'organization_id': 'organizationId',
            'deployment_id': 'deploymentId',
            'routing_target': 'routingTarget',
            'member_info': 'memberInfo',
            'member_auth_token': 'memberAuthToken',
            'journey_context': 'journeyContext'
        }

        self._organization_id = None
        self._deployment_id = None
        self._routing_target = None
        self._member_info = None
        self._member_auth_token = None
        self._journey_context = None

    @property
    def organization_id(self):
        """
        Gets the organization_id of this CreateWebChatConversationRequest.
        The organization identifier.

        :return: The organization_id of this CreateWebChatConversationRequest.
        :rtype: str
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """
        Sets the organization_id of this CreateWebChatConversationRequest.
        The organization identifier.

        :param organization_id: The organization_id of this CreateWebChatConversationRequest.
        :type: str
        """
        
        self._organization_id = organization_id

    @property
    def deployment_id(self):
        """
        Gets the deployment_id of this CreateWebChatConversationRequest.
        The web chat Deployment ID which contains the appropriate settings for this chat conversation.

        :return: The deployment_id of this CreateWebChatConversationRequest.
        :rtype: str
        """
        return self._deployment_id

    @deployment_id.setter
    def deployment_id(self, deployment_id):
        """
        Sets the deployment_id of this CreateWebChatConversationRequest.
        The web chat Deployment ID which contains the appropriate settings for this chat conversation.

        :param deployment_id: The deployment_id of this CreateWebChatConversationRequest.
        :type: str
        """
        
        self._deployment_id = deployment_id

    @property
    def routing_target(self):
        """
        Gets the routing_target of this CreateWebChatConversationRequest.
        The routing information to use for the new chat conversation.

        :return: The routing_target of this CreateWebChatConversationRequest.
        :rtype: WebChatRoutingTarget
        """
        return self._routing_target

    @routing_target.setter
    def routing_target(self, routing_target):
        """
        Sets the routing_target of this CreateWebChatConversationRequest.
        The routing information to use for the new chat conversation.

        :param routing_target: The routing_target of this CreateWebChatConversationRequest.
        :type: WebChatRoutingTarget
        """
        
        self._routing_target = routing_target

    @property
    def member_info(self):
        """
        Gets the member_info of this CreateWebChatConversationRequest.
        The guest member info to use for the new chat conversation.

        :return: The member_info of this CreateWebChatConversationRequest.
        :rtype: GuestMemberInfo
        """
        return self._member_info

    @member_info.setter
    def member_info(self, member_info):
        """
        Sets the member_info of this CreateWebChatConversationRequest.
        The guest member info to use for the new chat conversation.

        :param member_info: The member_info of this CreateWebChatConversationRequest.
        :type: GuestMemberInfo
        """
        
        self._member_info = member_info

    @property
    def member_auth_token(self):
        """
        Gets the member_auth_token of this CreateWebChatConversationRequest.
        If the guest member is an authenticated member (ie, not anonymous) his JWT is provided here. The token will have been previously generated with the \"POST /api/v2/signeddata\" resource.

        :return: The member_auth_token of this CreateWebChatConversationRequest.
        :rtype: str
        """
        return self._member_auth_token

    @member_auth_token.setter
    def member_auth_token(self, member_auth_token):
        """
        Sets the member_auth_token of this CreateWebChatConversationRequest.
        If the guest member is an authenticated member (ie, not anonymous) his JWT is provided here. The token will have been previously generated with the \"POST /api/v2/signeddata\" resource.

        :param member_auth_token: The member_auth_token of this CreateWebChatConversationRequest.
        :type: str
        """
        
        self._member_auth_token = member_auth_token

    @property
    def journey_context(self):
        """
        Gets the journey_context of this CreateWebChatConversationRequest.
        A subset of the Journey System's data relevant to this conversation/session request (for external linkage and internal usage/context).

        :return: The journey_context of this CreateWebChatConversationRequest.
        :rtype: JourneyContext
        """
        return self._journey_context

    @journey_context.setter
    def journey_context(self, journey_context):
        """
        Sets the journey_context of this CreateWebChatConversationRequest.
        A subset of the Journey System's data relevant to this conversation/session request (for external linkage and internal usage/context).

        :param journey_context: The journey_context of this CreateWebChatConversationRequest.
        :type: JourneyContext
        """
        
        self._journey_context = journey_context

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmAgentScheduleUpdateTopicWfmScheduleActivity(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmAgentScheduleUpdateTopicWfmScheduleActivity - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'activity_code_id': 'str',
            'start_date': 'datetime',
            'counts_as_paid_time': 'bool',
            'length_in_minutes': 'int',
            'time_off_request_id': 'str',
            'description': 'str'
        }

        self.attribute_map = {
            'activity_code_id': 'activityCodeId',
            'start_date': 'startDate',
            'counts_as_paid_time': 'countsAsPaidTime',
            'length_in_minutes': 'lengthInMinutes',
            'time_off_request_id': 'timeOffRequestId',
            'description': 'description'
        }

        self._activity_code_id = None
        self._start_date = None
        self._counts_as_paid_time = None
        self._length_in_minutes = None
        self._time_off_request_id = None
        self._description = None

    @property
    def activity_code_id(self):
        """
        Gets the activity_code_id of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.


        :return: The activity_code_id of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.
        :rtype: str
        """
        return self._activity_code_id

    @activity_code_id.setter
    def activity_code_id(self, activity_code_id):
        """
        Sets the activity_code_id of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.


        :param activity_code_id: The activity_code_id of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.
        :type: str
        """
        
        self._activity_code_id = activity_code_id

    @property
    def start_date(self):
        """
        Gets the start_date of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.


        :return: The start_date of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.


        :param start_date: The start_date of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.
        :type: datetime
        """
        
        self._start_date = start_date

    @property
    def counts_as_paid_time(self):
        """
        Gets the counts_as_paid_time of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.


        :return: The counts_as_paid_time of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.
        :rtype: bool
        """
        return self._counts_as_paid_time

    @counts_as_paid_time.setter
    def counts_as_paid_time(self, counts_as_paid_time):
        """
        Sets the counts_as_paid_time of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.


        :param counts_as_paid_time: The counts_as_paid_time of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.
        :type: bool
        """
        
        self._counts_as_paid_time = counts_as_paid_time

    @property
    def length_in_minutes(self):
        """
        Gets the length_in_minutes of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.


        :return: The length_in_minutes of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.
        :rtype: int
        """
        return self._length_in_minutes

    @length_in_minutes.setter
    def length_in_minutes(self, length_in_minutes):
        """
        Sets the length_in_minutes of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.


        :param length_in_minutes: The length_in_minutes of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.
        :type: int
        """
        
        self._length_in_minutes = length_in_minutes

    @property
    def time_off_request_id(self):
        """
        Gets the time_off_request_id of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.


        :return: The time_off_request_id of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.
        :rtype: str
        """
        return self._time_off_request_id

    @time_off_request_id.setter
    def time_off_request_id(self, time_off_request_id):
        """
        Sets the time_off_request_id of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.


        :param time_off_request_id: The time_off_request_id of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.
        :type: str
        """
        
        self._time_off_request_id = time_off_request_id

    @property
    def description(self):
        """
        Gets the description of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.


        :return: The description of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.


        :param description: The description of this WfmAgentScheduleUpdateTopicWfmScheduleActivity.
        :type: str
        """
        
        self._description = description

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class PatchTextStyleProperties(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        PatchTextStyleProperties - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'color': 'str',
            'font': 'str',
            'font_size': 'str',
            'text_align': 'str'
        }

        self.attribute_map = {
            'color': 'color',
            'font': 'font',
            'font_size': 'fontSize',
            'text_align': 'textAlign'
        }

        self._color = None
        self._font = None
        self._font_size = None
        self._text_align = None

    @property
    def color(self):
        """
        Gets the color of this PatchTextStyleProperties.
        Color of the text. (eg. #FFFFFF)

        :return: The color of this PatchTextStyleProperties.
        :rtype: str
        """
        return self._color

    @color.setter
    def color(self, color):
        """
        Sets the color of this PatchTextStyleProperties.
        Color of the text. (eg. #FFFFFF)

        :param color: The color of this PatchTextStyleProperties.
        :type: str
        """
        
        self._color = color

    @property
    def font(self):
        """
        Gets the font of this PatchTextStyleProperties.
        Font of the text. (eg. Helvetica)

        :return: The font of this PatchTextStyleProperties.
        :rtype: str
        """
        return self._font

    @font.setter
    def font(self, font):
        """
        Sets the font of this PatchTextStyleProperties.
        Font of the text. (eg. Helvetica)

        :param font: The font of this PatchTextStyleProperties.
        :type: str
        """
        
        self._font = font

    @property
    def font_size(self):
        """
        Gets the font_size of this PatchTextStyleProperties.
        Font size of the text. (eg. '12')

        :return: The font_size of this PatchTextStyleProperties.
        :rtype: str
        """
        return self._font_size

    @font_size.setter
    def font_size(self, font_size):
        """
        Sets the font_size of this PatchTextStyleProperties.
        Font size of the text. (eg. '12')

        :param font_size: The font_size of this PatchTextStyleProperties.
        :type: str
        """
        
        self._font_size = font_size

    @property
    def text_align(self):
        """
        Gets the text_align of this PatchTextStyleProperties.
        Text alignment.

        :return: The text_align of this PatchTextStyleProperties.
        :rtype: str
        """
        return self._text_align

    @text_align.setter
    def text_align(self, text_align):
        """
        Sets the text_align of this PatchTextStyleProperties.
        Text alignment.

        :param text_align: The text_align of this PatchTextStyleProperties.
        :type: str
        """
        allowed_values = ["Left", "Right", "Center"]
        if text_align.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for text_align -> " + text_align)
            self._text_align = "outdated_sdk_version"
        else:
            self._text_align = text_align

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class TimeZoneMappingPreview(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TimeZoneMappingPreview - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'contact_list': 'DomainEntityRef',
            'contacts_per_time_zone': 'dict(str, int)',
            'contacts_mapped_using_zip_code': 'dict(str, int)',
            'contacts_mapped_to_a_single_zone': 'int',
            'contacts_mapped_to_a_single_zone_using_zip_code': 'int',
            'contacts_mapped_to_multiple_zones': 'int',
            'contacts_mapped_to_multiple_zones_using_zip_code': 'int',
            'contacts_in_default_window': 'int',
            'contact_list_size': 'int'
        }

        self.attribute_map = {
            'contact_list': 'contactList',
            'contacts_per_time_zone': 'contactsPerTimeZone',
            'contacts_mapped_using_zip_code': 'contactsMappedUsingZipCode',
            'contacts_mapped_to_a_single_zone': 'contactsMappedToASingleZone',
            'contacts_mapped_to_a_single_zone_using_zip_code': 'contactsMappedToASingleZoneUsingZipCode',
            'contacts_mapped_to_multiple_zones': 'contactsMappedToMultipleZones',
            'contacts_mapped_to_multiple_zones_using_zip_code': 'contactsMappedToMultipleZonesUsingZipCode',
            'contacts_in_default_window': 'contactsInDefaultWindow',
            'contact_list_size': 'contactListSize'
        }

        self._contact_list = None
        self._contacts_per_time_zone = None
        self._contacts_mapped_using_zip_code = None
        self._contacts_mapped_to_a_single_zone = None
        self._contacts_mapped_to_a_single_zone_using_zip_code = None
        self._contacts_mapped_to_multiple_zones = None
        self._contacts_mapped_to_multiple_zones_using_zip_code = None
        self._contacts_in_default_window = None
        self._contact_list_size = None

    @property
    def contact_list(self):
        """
        Gets the contact_list of this TimeZoneMappingPreview.
        The associated ContactList

        :return: The contact_list of this TimeZoneMappingPreview.
        :rtype: DomainEntityRef
        """
        return self._contact_list

    @contact_list.setter
    def contact_list(self, contact_list):
        """
        Sets the contact_list of this TimeZoneMappingPreview.
        The associated ContactList

        :param contact_list: The contact_list of this TimeZoneMappingPreview.
        :type: DomainEntityRef
        """
        
        self._contact_list = contact_list

    @property
    def contacts_per_time_zone(self):
        """
        Gets the contacts_per_time_zone of this TimeZoneMappingPreview.
        The number of contacts per time zone that mapped to only that time zone

        :return: The contacts_per_time_zone of this TimeZoneMappingPreview.
        :rtype: dict(str, int)
        """
        return self._contacts_per_time_zone

    @contacts_per_time_zone.setter
    def contacts_per_time_zone(self, contacts_per_time_zone):
        """
        Sets the contacts_per_time_zone of this TimeZoneMappingPreview.
        The number of contacts per time zone that mapped to only that time zone

        :param contacts_per_time_zone: The contacts_per_time_zone of this TimeZoneMappingPreview.
        :type: dict(str, int)
        """
        
        self._contacts_per_time_zone = contacts_per_time_zone

    @property
    def contacts_mapped_using_zip_code(self):
        """
        Gets the contacts_mapped_using_zip_code of this TimeZoneMappingPreview.
        The number of contacts per time zone that mapped to only that time zone and were mapped using the zip code column

        :return: The contacts_mapped_using_zip_code of this TimeZoneMappingPreview.
        :rtype: dict(str, int)
        """
        return self._contacts_mapped_using_zip_code

    @contacts_mapped_using_zip_code.setter
    def contacts_mapped_using_zip_code(self, contacts_mapped_using_zip_code):
        """
        Sets the contacts_mapped_using_zip_code of this TimeZoneMappingPreview.
        The number of contacts per time zone that mapped to only that time zone and were mapped using the zip code column

        :param contacts_mapped_using_zip_code: The contacts_mapped_using_zip_code of this TimeZoneMappingPreview.
        :type: dict(str, int)
        """
        
        self._contacts_mapped_using_zip_code = contacts_mapped_using_zip_code

    @property
    def contacts_mapped_to_a_single_zone(self):
        """
        Gets the contacts_mapped_to_a_single_zone of this TimeZoneMappingPreview.
        The total number of contacts that mapped to a single time zone

        :return: The contacts_mapped_to_a_single_zone of this TimeZoneMappingPreview.
        :rtype: int
        """
        return self._contacts_mapped_to_a_single_zone

    @contacts_mapped_to_a_single_zone.setter
    def contacts_mapped_to_a_single_zone(self, contacts_mapped_to_a_single_zone):
        """
        Sets the contacts_mapped_to_a_single_zone of this TimeZoneMappingPreview.
        The total number of contacts that mapped to a single time zone

        :param contacts_mapped_to_a_single_zone: The contacts_mapped_to_a_single_zone of this TimeZoneMappingPreview.
        :type: int
        """
        
        self._contacts_mapped_to_a_single_zone = contacts_mapped_to_a_single_zone

    @property
    def contacts_mapped_to_a_single_zone_using_zip_code(self):
        """
        Gets the contacts_mapped_to_a_single_zone_using_zip_code of this TimeZoneMappingPreview.
        The total number of contacts that mapped to a single time zone and were mapped using the zip code column

        :return: The contacts_mapped_to_a_single_zone_using_zip_code of this TimeZoneMappingPreview.
        :rtype: int
        """
        return self._contacts_mapped_to_a_single_zone_using_zip_code

    @contacts_mapped_to_a_single_zone_using_zip_code.setter
    def contacts_mapped_to_a_single_zone_using_zip_code(self, contacts_mapped_to_a_single_zone_using_zip_code):
        """
        Sets the contacts_mapped_to_a_single_zone_using_zip_code of this TimeZoneMappingPreview.
        The total number of contacts that mapped to a single time zone and were mapped using the zip code column

        :param contacts_mapped_to_a_single_zone_using_zip_code: The contacts_mapped_to_a_single_zone_using_zip_code of this TimeZoneMappingPreview.
        :type: int
        """
        
        self._contacts_mapped_to_a_single_zone_using_zip_code = contacts_mapped_to_a_single_zone_using_zip_code

    @property
    def contacts_mapped_to_multiple_zones(self):
        """
        Gets the contacts_mapped_to_multiple_zones of this TimeZoneMappingPreview.
        The total number of contacts that mapped to multiple time zones

        :return: The contacts_mapped_to_multiple_zones of this TimeZoneMappingPreview.
        :rtype: int
        """
        return self._contacts_mapped_to_multiple_zones

    @contacts_mapped_to_multiple_zones.setter
    def contacts_mapped_to_multiple_zones(self, contacts_mapped_to_multiple_zones):
        """
        Sets the contacts_mapped_to_multiple_zones of this TimeZoneMappingPreview.
        The total number of contacts that mapped to multiple time zones

        :param contacts_mapped_to_multiple_zones: The contacts_mapped_to_multiple_zones of this TimeZoneMappingPreview.
        :type: int
        """
        
        self._contacts_mapped_to_multiple_zones = contacts_mapped_to_multiple_zones

    @property
    def contacts_mapped_to_multiple_zones_using_zip_code(self):
        """
        Gets the contacts_mapped_to_multiple_zones_using_zip_code of this TimeZoneMappingPreview.
        The total number of contacts that mapped to multiple time zones and were mapped using the zip code column

        :return: The contacts_mapped_to_multiple_zones_using_zip_code of this TimeZoneMappingPreview.
        :rtype: int
        """
        return self._contacts_mapped_to_multiple_zones_using_zip_code

    @contacts_mapped_to_multiple_zones_using_zip_code.setter
    def contacts_mapped_to_multiple_zones_using_zip_code(self, contacts_mapped_to_multiple_zones_using_zip_code):
        """
        Sets the contacts_mapped_to_multiple_zones_using_zip_code of this TimeZoneMappingPreview.
        The total number of contacts that mapped to multiple time zones and were mapped using the zip code column

        :param contacts_mapped_to_multiple_zones_using_zip_code: The contacts_mapped_to_multiple_zones_using_zip_code of this TimeZoneMappingPreview.
        :type: int
        """
        
        self._contacts_mapped_to_multiple_zones_using_zip_code = contacts_mapped_to_multiple_zones_using_zip_code

    @property
    def contacts_in_default_window(self):
        """
        Gets the contacts_in_default_window of this TimeZoneMappingPreview.
        The total number of contacts that will be dialed during the default window

        :return: The contacts_in_default_window of this TimeZoneMappingPreview.
        :rtype: int
        """
        return self._contacts_in_default_window

    @contacts_in_default_window.setter
    def contacts_in_default_window(self, contacts_in_default_window):
        """
        Sets the contacts_in_default_window of this TimeZoneMappingPreview.
        The total number of contacts that will be dialed during the default window

        :param contacts_in_default_window: The contacts_in_default_window of this TimeZoneMappingPreview.
        :type: int
        """
        
        self._contacts_in_default_window = contacts_in_default_window

    @property
    def contact_list_size(self):
        """
        Gets the contact_list_size of this TimeZoneMappingPreview.
        The total number of contacts in the contact list

        :return: The contact_list_size of this TimeZoneMappingPreview.
        :rtype: int
        """
        return self._contact_list_size

    @contact_list_size.setter
    def contact_list_size(self, contact_list_size):
        """
        Sets the contact_list_size of this TimeZoneMappingPreview.
        The total number of contacts in the contact list

        :param contact_list_size: The contact_list_size of this TimeZoneMappingPreview.
        :type: int
        """
        
        self._contact_list_size = contact_list_size

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ContentOfferStylingConfiguration(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ContentOfferStylingConfiguration - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'position': 'ContentPositionProperties',
            'offer': 'ContentOfferStyleProperties',
            'close_button': 'CloseButtonStyleProperties',
            'cta_button': 'CtaButtonStyleProperties',
            'title': 'TextStyleProperties',
            'headline': 'TextStyleProperties',
            'body': 'TextStyleProperties'
        }

        self.attribute_map = {
            'position': 'position',
            'offer': 'offer',
            'close_button': 'closeButton',
            'cta_button': 'ctaButton',
            'title': 'title',
            'headline': 'headline',
            'body': 'body'
        }

        self._position = None
        self._offer = None
        self._close_button = None
        self._cta_button = None
        self._title = None
        self._headline = None
        self._body = None

    @property
    def position(self):
        """
        Gets the position of this ContentOfferStylingConfiguration.
        Properties for customizing the positioning of the content offer.

        :return: The position of this ContentOfferStylingConfiguration.
        :rtype: ContentPositionProperties
        """
        return self._position

    @position.setter
    def position(self, position):
        """
        Sets the position of this ContentOfferStylingConfiguration.
        Properties for customizing the positioning of the content offer.

        :param position: The position of this ContentOfferStylingConfiguration.
        :type: ContentPositionProperties
        """
        
        self._position = position

    @property
    def offer(self):
        """
        Gets the offer of this ContentOfferStylingConfiguration.
        Properties for customizing the appearance of the content offer.

        :return: The offer of this ContentOfferStylingConfiguration.
        :rtype: ContentOfferStyleProperties
        """
        return self._offer

    @offer.setter
    def offer(self, offer):
        """
        Sets the offer of this ContentOfferStylingConfiguration.
        Properties for customizing the appearance of the content offer.

        :param offer: The offer of this ContentOfferStylingConfiguration.
        :type: ContentOfferStyleProperties
        """
        
        self._offer = offer

    @property
    def close_button(self):
        """
        Gets the close_button of this ContentOfferStylingConfiguration.
        Properties for customizing the appearance of the close button.

        :return: The close_button of this ContentOfferStylingConfiguration.
        :rtype: CloseButtonStyleProperties
        """
        return self._close_button

    @close_button.setter
    def close_button(self, close_button):
        """
        Sets the close_button of this ContentOfferStylingConfiguration.
        Properties for customizing the appearance of the close button.

        :param close_button: The close_button of this ContentOfferStylingConfiguration.
        :type: CloseButtonStyleProperties
        """
        
        self._close_button = close_button

    @property
    def cta_button(self):
        """
        Gets the cta_button of this ContentOfferStylingConfiguration.
        Properties for customizing the appearance of the CTA button.

        :return: The cta_button of this ContentOfferStylingConfiguration.
        :rtype: CtaButtonStyleProperties
        """
        return self._cta_button

    @cta_button.setter
    def cta_button(self, cta_button):
        """
        Sets the cta_button of this ContentOfferStylingConfiguration.
        Properties for customizing the appearance of the CTA button.

        :param cta_button: The cta_button of this ContentOfferStylingConfiguration.
        :type: CtaButtonStyleProperties
        """
        
        self._cta_button = cta_button

    @property
    def title(self):
        """
        Gets the title of this ContentOfferStylingConfiguration.
        Properties for customizing the appearance of the title text.

        :return: The title of this ContentOfferStylingConfiguration.
        :rtype: TextStyleProperties
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this ContentOfferStylingConfiguration.
        Properties for customizing the appearance of the title text.

        :param title: The title of this ContentOfferStylingConfiguration.
        :type: TextStyleProperties
        """
        
        self._title = title

    @property
    def headline(self):
        """
        Gets the headline of this ContentOfferStylingConfiguration.
        Properties for customizing the appearance of the headline text.

        :return: The headline of this ContentOfferStylingConfiguration.
        :rtype: TextStyleProperties
        """
        return self._headline

    @headline.setter
    def headline(self, headline):
        """
        Sets the headline of this ContentOfferStylingConfiguration.
        Properties for customizing the appearance of the headline text.

        :param headline: The headline of this ContentOfferStylingConfiguration.
        :type: TextStyleProperties
        """
        
        self._headline = headline

    @property
    def body(self):
        """
        Gets the body of this ContentOfferStylingConfiguration.
        Properties for customizing the appearance of the body text.

        :return: The body of this ContentOfferStylingConfiguration.
        :rtype: TextStyleProperties
        """
        return self._body

    @body.setter
    def body(self, body):
        """
        Sets the body of this ContentOfferStylingConfiguration.
        Properties for customizing the appearance of the body text.

        :param body: The body of this ContentOfferStylingConfiguration.
        :type: TextStyleProperties
        """
        
        self._body = body

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class RecordingJob(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        RecordingJob - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'state': 'str',
            'recording_jobs_query': 'RecordingJobsQuery',
            'date_created': 'datetime',
            'total_conversations': 'int',
            'total_recordings': 'int',
            'total_processed_recordings': 'int',
            'percent_progress': 'int',
            'error_message': 'str',
            'self_uri': 'str',
            'user': 'AddressableEntityRef'
        }

        self.attribute_map = {
            'id': 'id',
            'state': 'state',
            'recording_jobs_query': 'recordingJobsQuery',
            'date_created': 'dateCreated',
            'total_conversations': 'totalConversations',
            'total_recordings': 'totalRecordings',
            'total_processed_recordings': 'totalProcessedRecordings',
            'percent_progress': 'percentProgress',
            'error_message': 'errorMessage',
            'self_uri': 'selfUri',
            'user': 'user'
        }

        self._id = None
        self._state = None
        self._recording_jobs_query = None
        self._date_created = None
        self._total_conversations = None
        self._total_recordings = None
        self._total_processed_recordings = None
        self._percent_progress = None
        self._error_message = None
        self._self_uri = None
        self._user = None

    @property
    def id(self):
        """
        Gets the id of this RecordingJob.
        The globally unique identifier for the object.

        :return: The id of this RecordingJob.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this RecordingJob.
        The globally unique identifier for the object.

        :param id: The id of this RecordingJob.
        :type: str
        """
        
        self._id = id

    @property
    def state(self):
        """
        Gets the state of this RecordingJob.
        The current state of the job.

        :return: The state of this RecordingJob.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this RecordingJob.
        The current state of the job.

        :param state: The state of this RecordingJob.
        :type: str
        """
        allowed_values = ["FULFILLED", "PENDING", "READY", "PROCESSING", "CANCELLED", "FAILED"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def recording_jobs_query(self):
        """
        Gets the recording_jobs_query of this RecordingJob.
        Original query of the job.

        :return: The recording_jobs_query of this RecordingJob.
        :rtype: RecordingJobsQuery
        """
        return self._recording_jobs_query

    @recording_jobs_query.setter
    def recording_jobs_query(self, recording_jobs_query):
        """
        Sets the recording_jobs_query of this RecordingJob.
        Original query of the job.

        :param recording_jobs_query: The recording_jobs_query of this RecordingJob.
        :type: RecordingJobsQuery
        """
        
        self._recording_jobs_query = recording_jobs_query

    @property
    def date_created(self):
        """
        Gets the date_created of this RecordingJob.
        Date when the job was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this RecordingJob.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this RecordingJob.
        Date when the job was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this RecordingJob.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def total_conversations(self):
        """
        Gets the total_conversations of this RecordingJob.
        Total number of conversations affected.

        :return: The total_conversations of this RecordingJob.
        :rtype: int
        """
        return self._total_conversations

    @total_conversations.setter
    def total_conversations(self, total_conversations):
        """
        Sets the total_conversations of this RecordingJob.
        Total number of conversations affected.

        :param total_conversations: The total_conversations of this RecordingJob.
        :type: int
        """
        
        self._total_conversations = total_conversations

    @property
    def total_recordings(self):
        """
        Gets the total_recordings of this RecordingJob.
        Total number of recordings affected.

        :return: The total_recordings of this RecordingJob.
        :rtype: int
        """
        return self._total_recordings

    @total_recordings.setter
    def total_recordings(self, total_recordings):
        """
        Sets the total_recordings of this RecordingJob.
        Total number of recordings affected.

        :param total_recordings: The total_recordings of this RecordingJob.
        :type: int
        """
        
        self._total_recordings = total_recordings

    @property
    def total_processed_recordings(self):
        """
        Gets the total_processed_recordings of this RecordingJob.
        Total number of recordings have been processed.

        :return: The total_processed_recordings of this RecordingJob.
        :rtype: int
        """
        return self._total_processed_recordings

    @total_processed_recordings.setter
    def total_processed_recordings(self, total_processed_recordings):
        """
        Sets the total_processed_recordings of this RecordingJob.
        Total number of recordings have been processed.

        :param total_processed_recordings: The total_processed_recordings of this RecordingJob.
        :type: int
        """
        
        self._total_processed_recordings = total_processed_recordings

    @property
    def percent_progress(self):
        """
        Gets the percent_progress of this RecordingJob.
        Progress in percentage based on the number of recordings

        :return: The percent_progress of this RecordingJob.
        :rtype: int
        """
        return self._percent_progress

    @percent_progress.setter
    def percent_progress(self, percent_progress):
        """
        Sets the percent_progress of this RecordingJob.
        Progress in percentage based on the number of recordings

        :param percent_progress: The percent_progress of this RecordingJob.
        :type: int
        """
        
        self._percent_progress = percent_progress

    @property
    def error_message(self):
        """
        Gets the error_message of this RecordingJob.
        Error occurred during the job execution

        :return: The error_message of this RecordingJob.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """
        Sets the error_message of this RecordingJob.
        Error occurred during the job execution

        :param error_message: The error_message of this RecordingJob.
        :type: str
        """
        
        self._error_message = error_message

    @property
    def self_uri(self):
        """
        Gets the self_uri of this RecordingJob.
        The URI for this object

        :return: The self_uri of this RecordingJob.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this RecordingJob.
        The URI for this object

        :param self_uri: The self_uri of this RecordingJob.
        :type: str
        """
        
        self._self_uri = self_uri

    @property
    def user(self):
        """
        Gets the user of this RecordingJob.
        Details of the user created the job

        :return: The user of this RecordingJob.
        :rtype: AddressableEntityRef
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this RecordingJob.
        Details of the user created the job

        :param user: The user of this RecordingJob.
        :type: AddressableEntityRef
        """
        
        self._user = user

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class EdgeMetricsTopicEdgeMetrics(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EdgeMetricsTopicEdgeMetrics - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'edge': 'EdgeMetricsTopicUriReference',
            'event_time': 'EdgeMetricsTopicOffsetDateTime',
            'up_time_msec': 'int',
            'processors': 'list[EdgeMetricsTopicEdgeMetricProcessor]',
            'memory': 'list[EdgeMetricsTopicEdgeMetricMemory]',
            'disks': 'list[EdgeMetricsTopicEdgeMetricDisk]',
            'subsystems': 'list[EdgeMetricsTopicEdgeMetricSubsystem]',
            'networks': 'list[EdgeMetricsTopicEdgeMetricNetworks]'
        }

        self.attribute_map = {
            'edge': 'edge',
            'event_time': 'eventTime',
            'up_time_msec': 'upTimeMsec',
            'processors': 'processors',
            'memory': 'memory',
            'disks': 'disks',
            'subsystems': 'subsystems',
            'networks': 'networks'
        }

        self._edge = None
        self._event_time = None
        self._up_time_msec = None
        self._processors = None
        self._memory = None
        self._disks = None
        self._subsystems = None
        self._networks = None

    @property
    def edge(self):
        """
        Gets the edge of this EdgeMetricsTopicEdgeMetrics.


        :return: The edge of this EdgeMetricsTopicEdgeMetrics.
        :rtype: EdgeMetricsTopicUriReference
        """
        return self._edge

    @edge.setter
    def edge(self, edge):
        """
        Sets the edge of this EdgeMetricsTopicEdgeMetrics.


        :param edge: The edge of this EdgeMetricsTopicEdgeMetrics.
        :type: EdgeMetricsTopicUriReference
        """
        
        self._edge = edge

    @property
    def event_time(self):
        """
        Gets the event_time of this EdgeMetricsTopicEdgeMetrics.


        :return: The event_time of this EdgeMetricsTopicEdgeMetrics.
        :rtype: EdgeMetricsTopicOffsetDateTime
        """
        return self._event_time

    @event_time.setter
    def event_time(self, event_time):
        """
        Sets the event_time of this EdgeMetricsTopicEdgeMetrics.


        :param event_time: The event_time of this EdgeMetricsTopicEdgeMetrics.
        :type: EdgeMetricsTopicOffsetDateTime
        """
        
        self._event_time = event_time

    @property
    def up_time_msec(self):
        """
        Gets the up_time_msec of this EdgeMetricsTopicEdgeMetrics.


        :return: The up_time_msec of this EdgeMetricsTopicEdgeMetrics.
        :rtype: int
        """
        return self._up_time_msec

    @up_time_msec.setter
    def up_time_msec(self, up_time_msec):
        """
        Sets the up_time_msec of this EdgeMetricsTopicEdgeMetrics.


        :param up_time_msec: The up_time_msec of this EdgeMetricsTopicEdgeMetrics.
        :type: int
        """
        
        self._up_time_msec = up_time_msec

    @property
    def processors(self):
        """
        Gets the processors of this EdgeMetricsTopicEdgeMetrics.


        :return: The processors of this EdgeMetricsTopicEdgeMetrics.
        :rtype: list[EdgeMetricsTopicEdgeMetricProcessor]
        """
        return self._processors

    @processors.setter
    def processors(self, processors):
        """
        Sets the processors of this EdgeMetricsTopicEdgeMetrics.


        :param processors: The processors of this EdgeMetricsTopicEdgeMetrics.
        :type: list[EdgeMetricsTopicEdgeMetricProcessor]
        """
        
        self._processors = processors

    @property
    def memory(self):
        """
        Gets the memory of this EdgeMetricsTopicEdgeMetrics.


        :return: The memory of this EdgeMetricsTopicEdgeMetrics.
        :rtype: list[EdgeMetricsTopicEdgeMetricMemory]
        """
        return self._memory

    @memory.setter
    def memory(self, memory):
        """
        Sets the memory of this EdgeMetricsTopicEdgeMetrics.


        :param memory: The memory of this EdgeMetricsTopicEdgeMetrics.
        :type: list[EdgeMetricsTopicEdgeMetricMemory]
        """
        
        self._memory = memory

    @property
    def disks(self):
        """
        Gets the disks of this EdgeMetricsTopicEdgeMetrics.


        :return: The disks of this EdgeMetricsTopicEdgeMetrics.
        :rtype: list[EdgeMetricsTopicEdgeMetricDisk]
        """
        return self._disks

    @disks.setter
    def disks(self, disks):
        """
        Sets the disks of this EdgeMetricsTopicEdgeMetrics.


        :param disks: The disks of this EdgeMetricsTopicEdgeMetrics.
        :type: list[EdgeMetricsTopicEdgeMetricDisk]
        """
        
        self._disks = disks

    @property
    def subsystems(self):
        """
        Gets the subsystems of this EdgeMetricsTopicEdgeMetrics.


        :return: The subsystems of this EdgeMetricsTopicEdgeMetrics.
        :rtype: list[EdgeMetricsTopicEdgeMetricSubsystem]
        """
        return self._subsystems

    @subsystems.setter
    def subsystems(self, subsystems):
        """
        Sets the subsystems of this EdgeMetricsTopicEdgeMetrics.


        :param subsystems: The subsystems of this EdgeMetricsTopicEdgeMetrics.
        :type: list[EdgeMetricsTopicEdgeMetricSubsystem]
        """
        
        self._subsystems = subsystems

    @property
    def networks(self):
        """
        Gets the networks of this EdgeMetricsTopicEdgeMetrics.


        :return: The networks of this EdgeMetricsTopicEdgeMetrics.
        :rtype: list[EdgeMetricsTopicEdgeMetricNetworks]
        """
        return self._networks

    @networks.setter
    def networks(self, networks):
        """
        Sets the networks of this EdgeMetricsTopicEdgeMetrics.


        :param networks: The networks of this EdgeMetricsTopicEdgeMetrics.
        :type: list[EdgeMetricsTopicEdgeMetricNetworks]
        """
        
        self._networks = networks

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class NluDomainVersion(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        NluDomainVersion - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'domain': 'NluDomain',
            'description': 'str',
            'language': 'str',
            'published': 'bool',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'date_trained': 'datetime',
            'date_published': 'datetime',
            'training_status': 'str',
            'evaluation_status': 'str',
            'intents': 'list[IntentDefinition]',
            'entity_types': 'list[NamedEntityTypeDefinition]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'domain': 'domain',
            'description': 'description',
            'language': 'language',
            'published': 'published',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'date_trained': 'dateTrained',
            'date_published': 'datePublished',
            'training_status': 'trainingStatus',
            'evaluation_status': 'evaluationStatus',
            'intents': 'intents',
            'entity_types': 'entityTypes',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._domain = None
        self._description = None
        self._language = None
        self._published = None
        self._date_created = None
        self._date_modified = None
        self._date_trained = None
        self._date_published = None
        self._training_status = None
        self._evaluation_status = None
        self._intents = None
        self._entity_types = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this NluDomainVersion.
        The globally unique identifier for the object.

        :return: The id of this NluDomainVersion.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this NluDomainVersion.
        The globally unique identifier for the object.

        :param id: The id of this NluDomainVersion.
        :type: str
        """
        
        self._id = id

    @property
    def domain(self):
        """
        Gets the domain of this NluDomainVersion.
        The NLU domain of the version.

        :return: The domain of this NluDomainVersion.
        :rtype: NluDomain
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """
        Sets the domain of this NluDomainVersion.
        The NLU domain of the version.

        :param domain: The domain of this NluDomainVersion.
        :type: NluDomain
        """
        
        self._domain = domain

    @property
    def description(self):
        """
        Gets the description of this NluDomainVersion.
        The description of the NLU domain version.

        :return: The description of this NluDomainVersion.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this NluDomainVersion.
        The description of the NLU domain version.

        :param description: The description of this NluDomainVersion.
        :type: str
        """
        
        self._description = description

    @property
    def language(self):
        """
        Gets the language of this NluDomainVersion.
        The language that the NLU domain version supports.

        :return: The language of this NluDomainVersion.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        Sets the language of this NluDomainVersion.
        The language that the NLU domain version supports.

        :param language: The language of this NluDomainVersion.
        :type: str
        """
        
        self._language = language

    @property
    def published(self):
        """
        Gets the published of this NluDomainVersion.
        Whether this NLU domain version has been published.

        :return: The published of this NluDomainVersion.
        :rtype: bool
        """
        return self._published

    @published.setter
    def published(self, published):
        """
        Sets the published of this NluDomainVersion.
        Whether this NLU domain version has been published.

        :param published: The published of this NluDomainVersion.
        :type: bool
        """
        
        self._published = published

    @property
    def date_created(self):
        """
        Gets the date_created of this NluDomainVersion.
        The date when the NLU domain version was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this NluDomainVersion.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this NluDomainVersion.
        The date when the NLU domain version was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this NluDomainVersion.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this NluDomainVersion.
        The date when the NLU domain version was updated. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this NluDomainVersion.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this NluDomainVersion.
        The date when the NLU domain version was updated. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this NluDomainVersion.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def date_trained(self):
        """
        Gets the date_trained of this NluDomainVersion.
        The date when the NLU domain version was trained. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_trained of this NluDomainVersion.
        :rtype: datetime
        """
        return self._date_trained

    @date_trained.setter
    def date_trained(self, date_trained):
        """
        Sets the date_trained of this NluDomainVersion.
        The date when the NLU domain version was trained. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_trained: The date_trained of this NluDomainVersion.
        :type: datetime
        """
        
        self._date_trained = date_trained

    @property
    def date_published(self):
        """
        Gets the date_published of this NluDomainVersion.
        The date when the NLU domain version was published. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_published of this NluDomainVersion.
        :rtype: datetime
        """
        return self._date_published

    @date_published.setter
    def date_published(self, date_published):
        """
        Sets the date_published of this NluDomainVersion.
        The date when the NLU domain version was published. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_published: The date_published of this NluDomainVersion.
        :type: datetime
        """
        
        self._date_published = date_published

    @property
    def training_status(self):
        """
        Gets the training_status of this NluDomainVersion.
        The training status of the NLU domain version.

        :return: The training_status of this NluDomainVersion.
        :rtype: str
        """
        return self._training_status

    @training_status.setter
    def training_status(self, training_status):
        """
        Sets the training_status of this NluDomainVersion.
        The training status of the NLU domain version.

        :param training_status: The training_status of this NluDomainVersion.
        :type: str
        """
        allowed_values = ["Untrained", "Training", "Trained", "Error", "Unknown"]
        if training_status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for training_status -> " + training_status)
            self._training_status = "outdated_sdk_version"
        else:
            self._training_status = training_status

    @property
    def evaluation_status(self):
        """
        Gets the evaluation_status of this NluDomainVersion.
        The evaluation status of the NLU domain version.

        :return: The evaluation_status of this NluDomainVersion.
        :rtype: str
        """
        return self._evaluation_status

    @evaluation_status.setter
    def evaluation_status(self, evaluation_status):
        """
        Sets the evaluation_status of this NluDomainVersion.
        The evaluation status of the NLU domain version.

        :param evaluation_status: The evaluation_status of this NluDomainVersion.
        :type: str
        """
        allowed_values = ["Unevaluated", "Evaluating", "Evaluated", "Error"]
        if evaluation_status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for evaluation_status -> " + evaluation_status)
            self._evaluation_status = "outdated_sdk_version"
        else:
            self._evaluation_status = evaluation_status

    @property
    def intents(self):
        """
        Gets the intents of this NluDomainVersion.
        The intents defined for this NLU domain version.

        :return: The intents of this NluDomainVersion.
        :rtype: list[IntentDefinition]
        """
        return self._intents

    @intents.setter
    def intents(self, intents):
        """
        Sets the intents of this NluDomainVersion.
        The intents defined for this NLU domain version.

        :param intents: The intents of this NluDomainVersion.
        :type: list[IntentDefinition]
        """
        
        self._intents = intents

    @property
    def entity_types(self):
        """
        Gets the entity_types of this NluDomainVersion.
        The entity types defined for this NLU domain version.

        :return: The entity_types of this NluDomainVersion.
        :rtype: list[NamedEntityTypeDefinition]
        """
        return self._entity_types

    @entity_types.setter
    def entity_types(self, entity_types):
        """
        Sets the entity_types of this NluDomainVersion.
        The entity types defined for this NLU domain version.

        :param entity_types: The entity_types of this NluDomainVersion.
        :type: list[NamedEntityTypeDefinition]
        """
        
        self._entity_types = entity_types

    @property
    def self_uri(self):
        """
        Gets the self_uri of this NluDomainVersion.
        The URI for this object

        :return: The self_uri of this NluDomainVersion.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this NluDomainVersion.
        The URI for this object

        :param self_uri: The self_uri of this NluDomainVersion.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

